@@ -125,6 +125,7 @@ static int zflookupobj(ZFMAP*, const char* key, FD* fd);
 static int zfparseurl(const char* path0, NCURI** urip);
 static int zffullpath(ZFMAP* zfmap, const char* key, char**);
 static void zfrelease(ZFMAP* zfmap, FD* fd);
+static void zfunlink(const char* canonpath);
 
 static int platformerr(int err);
 static int platformcreatefile(ZFMAP* map, const char* truepath,FD*);
@@ -141,10 +142,12 @@ static int platformtestcontentbearing(ZFMAP* zfmap, const char* truepath);
 
 #ifdef VERIFY
 static int verify(const char* path, int isdir);
+static int verifykey(const char* key, int isdir);
 #endif
 
 static int zfinitialized = 0;
-static void zfinitialize(void)
+static void
+zfileinitialize(void)
 {
     if(!zfinitialized) {
         ZTRACE(5,NULL);
@@ -178,14 +181,15 @@ static int
 zfilecreate(const char *path, int mode, size64_t flags, void* parameters, NCZMAP** mapp)
 {
     int stat = NC_NOERR;
-    char* truepath = NULL;
+    char* canonpath = NULL;
+    char* abspath = NULL;
     ZFMAP* zfmap = NULL;
     NCURI* url = NULL;
 	
     NC_UNUSED(parameters);
     ZTRACE(5,"path=%s mode=%d flag=%llu",path,mode,flags);
 
-    if(!zfinitialized) zfinitialize();
+    if(!zfinitialized) zfileinitialize();
 
     /* Fixup mode flags */
     mode |= (NC_NETCDF4 | NC_WRITE);
@@ -199,15 +203,15 @@ zfilecreate(const char *path, int mode, size64_t flags, void* parameters, NCZMAP
     if(strcasecmp(url->protocol,"file") != 0)
         {stat = NC_EURL; goto done;}
 
-    /* Canonicalize the root path */
-    if((stat = nczm_canonicalpath(url->path,&truepath))) goto done;
+    /* Convert the root path */
+    if((canonpath = NCpathcvt(url->path))==NULL)
+	{stat = NC_ENOMEM; goto done;}
 
-#ifdef CHECKNESTEDDATASETS
-    if(isnesteddataset(truepath))
-        {stat = NC_ENCZARR; goto done;}
-#endif
+    /* Make the root path be absolute */
+    if((abspath = NCpathabsolute(canonpath)) == NULL)
+	{stat = NC_EURL; goto done;}
 
-    /* Build the z4 state */
+    /* Build the zmap state */
     if((zfmap = calloc(1,sizeof(ZFMAP))) == NULL)
 	{stat = NC_ENOMEM; goto done;}
 
@@ -217,8 +221,8 @@ zfilecreate(const char *path, int mode, size64_t flags, void* parameters, NCZMAP
     /* create => NC_WRITE */
     zfmap->map.mode = mode;
     zfmap->map.api = &zapi;
-    zfmap->root = truepath;
-        truepath = NULL;
+    zfmap->root = abspath;
+        abspath = NULL;
 
     /* If NC_CLOBBER, then delete below file tree */
     if(!fIsSet(mode,NC_NOCLOBBER))
@@ -234,7 +238,8 @@ zfilecreate(const char *path, int mode, size64_t flags, void* parameters, NCZMAP
 
 done:
     ncurifree(url);
-    nullfree(truepath);
+    nullfree(canonpath);
+    nullfree(abspath);
     if(stat)
     	zfileclose((NCZMAP*)zfmap,1);
     return ZUNTRACE(stat);
@@ -253,14 +258,15 @@ static int
 zfileopen(const char *path, int mode, size64_t flags, void* parameters, NCZMAP** mapp)
 {
     int stat = NC_NOERR;
-    char* truepath = NULL;
+    char* canonpath = NULL;
+    char* abspath = NULL;
     ZFMAP* zfmap = NULL;
     NCURI*url = NULL;
     
     NC_UNUSED(parameters);
     ZTRACE(5,"path=%s mode=%d flags=%llu",path,mode,flags);
 
-    if(!zfinitialized) zfinitialize();
+    if(!zfinitialized) zfileinitialize();
 
     /* Fixup mode flags */
     mode = (NC_NETCDF4 | mode);
@@ -271,10 +277,15 @@ zfileopen(const char *path, int mode, size64_t flags, void* parameters, NCZMAP**
     if(strcasecmp(url->protocol,"file") != 0)
         {stat = NC_EURL; goto done;}
 
-    /* Canonicalize the root path */
-    if((stat = nczm_canonicalpath(url->path,&truepath))) goto done;
+    /* Convert the root path */
+    if((canonpath = NCpathcvt(url->path))==NULL)
+	{stat = NC_ENOMEM; goto done;}
 
-    /* Build the z4 state */
+    /* Make the root path be absolute */
+    if((abspath = NCpathabsolute(canonpath)) == NULL)
+	{stat = NC_EURL; goto done;}
+
+    /* Build the zmap state */
     if((zfmap = calloc(1,sizeof(ZFMAP))) == NULL)
 	{stat = NC_ENOMEM; goto done;}
 
@@ -283,8 +294,8 @@ zfileopen(const char *path, int mode, size64_t flags, void* parameters, NCZMAP**
     zfmap->map.flags = flags;
     zfmap->map.mode = mode;
     zfmap->map.api = (NCZMAP_API*)&zapi;
-    zfmap->root = truepath;
-	truepath = NULL;
+    zfmap->root = abspath;
+	abspath = NULL;
     
     /* Verify root dir exists */
     if((stat = platformopendir(zfmap,zfmap->root)))
@@ -296,7 +307,8 @@ zfileopen(const char *path, int mode, size64_t flags, void* parameters, NCZMAP**
 
 done:
     ncurifree(url);
-    nullfree(truepath);
+    nullfree(canonpath);
+    nullfree(abspath);
     if(stat) zfileclose((NCZMAP*)zfmap,0);
     return ZUNTRACE(stat);
 }
@@ -314,7 +326,7 @@ zfileexists(NCZMAP* map, const char* key)
     ZTRACE(5,"map=%s key=%s",zfmap->map.url,key);
     switch(stat=zflookupobj(zfmap,key,&fd)) {
     case NC_NOERR: break;
-    case NC_ENOTFOUND: stat = NC_EEMPTY;
+    case NC_ENOOBJECT: stat = NC_EEMPTY;
     case NC_EEMPTY: break;
     default: break;
     }
@@ -337,7 +349,7 @@ zfilelen(NCZMAP* map, const char* key, size64_t* lenp)
         /* Get file size */
         if((stat=platformseek(zfmap, &fd, SEEK_END, &len))) goto done;
 	break;
-    case NC_ENOTFOUND: stat = NC_EEMPTY;
+    case NC_ENOOBJECT: stat = NC_EEMPTY;
     case NC_EEMPTY: break;
     default: break;
     }
@@ -358,7 +370,7 @@ zfileread(NCZMAP* map, const char* key, size64_t start, size64_t count, void* co
     ZTRACE(5,"map=%s key=%s start=%llu count=%llu",map->url,key,start,count);
 
 #ifdef VERIFY
-    if(!verify(key,!FLAG_ISDIR))
+    if(!verifykey(key,!FLAG_ISDIR))
         assert(!"expected file, have dir");
 #endif
 
@@ -367,7 +379,7 @@ zfileread(NCZMAP* map, const char* key, size64_t start, size64_t count, void* co
         if((stat = platformseek(zfmap, &fd, SEEK_SET, &start))) goto done;
         if((stat = platformread(zfmap, &fd, count, content))) goto done;
 	break;
-    case NC_ENOTFOUND: stat = NC_EEMPTY;
+    case NC_ENOOBJECT: stat = NC_EEMPTY;
     case NC_EEMPTY: break;
     default: break;
     }
@@ -388,13 +400,14 @@ zfilewrite(NCZMAP* map, const char* key, size64_t start, size64_t count, const v
     ZTRACE(5,"map=%s key=%s start=%llu count=%llu",map->url,key,start,count);
 
 #ifdef VERIFY
-    if(!verify(key,!FLAG_ISDIR))
+    if(!verifykey(key,!FLAG_ISDIR))
         assert(!"expected file, have dir");
 #endif
 
     switch (stat = zflookupobj(zfmap,key,&fd)) {
-    case NC_ENOTFOUND:
+    case NC_ENOOBJECT:
     case NC_EEMPTY:
+	stat = NC_NOERR;
 	/* Create the directories leading to this */
 	if((stat = zfcreategroup(zfmap,key,SKIPLAST))) goto done;
         /* Create truepath */
@@ -427,7 +440,7 @@ zfileclose(NCZMAP* map, int delete)
     /* Delete the subtree below the root and the root */
     if(delete) {
 	stat = platformdelete(zfmap,zfmap->root,1);
-	unlink(zfmap->root);
+	zfunlink(zfmap->root);
     }
     nczm_clear(map);
     nullfree(zfmap->root);
@@ -447,7 +460,7 @@ zfilesearch(NCZMAP* map, const char* prefixkey, NClist* matches)
 {
     int stat = NC_NOERR;
     ZFMAP* zfmap = (ZFMAP*)map;
-    char* truepath = NULL;
+    char* fullpath = NULL;
     NClist* nextlevel = nclistnew();
     NCbytes* buf = ncbytesnew();
 
@@ -455,17 +468,17 @@ zfilesearch(NCZMAP* map, const char* prefixkey, NClist* matches)
 
     /* Make the root path be true */
     if(prefixkey == NULL || strlen(prefixkey)==0 || strcmp(prefixkey,"/")==0)
-	truepath = strdup(zfmap->root);
-    else if((stat = nczm_concat(zfmap->root,prefixkey,&truepath))) goto done;
+	fullpath = strdup(zfmap->root);
+    else if((stat = nczm_concat(zfmap->root,prefixkey,&fullpath))) goto done;
 
     /* get names of the next level path entries */
-    switch (stat = platformdircontent(zfmap, truepath, nextlevel)) {
+    switch (stat = platformdircontent(zfmap, fullpath, nextlevel)) {
     case NC_NOERR: /* ok */
 	break;
     case NC_EEMPTY: /* not a dir */
 	stat = NC_NOERR;
 	goto done;
-    case NC_ENOTFOUND: /* does not exist */
+    case NC_ENOOBJECT:
     default:
 	goto done;
     }
@@ -477,13 +490,23 @@ zfilesearch(NCZMAP* map, const char* prefixkey, NClist* matches)
 done:
     nclistfreeall(nextlevel);
     ncbytesfree(buf);
-    nullfree(truepath);
+    nullfree(fullpath);
     return ZUNTRACEX(stat,"|matches|=%d",(int)nclistlength(matches));
 }
 
 /**************************************************/
 /* Utilities */
 
+static void
+zfunlink(const char* canonpath)
+{
+    char* local = NULL;
+    if((local = NCpathcvt(canonpath))==NULL) goto done;
+    unlink(local);
+done:
+    nullfree(local);
+}
+
 /* Lookup a group by parsed path (segments)*/
 /* Return NC_EEMPTY if not found, NC_EINVAL if not a directory; create if create flag is set */
 static int
@@ -519,7 +542,7 @@ done:
 /* Lookup an object
 @return NC_NOERR if found and is a content-bearing object
 @return NC_EEMPTY if exists but is not-content-bearing
-@return NC_ENOTFOUND if not found
+@return NC_ENOOBJECT if not found
 */
 static int
 zflookupobj(ZFMAP* zfmap, const char* key, FD* fd)
@@ -582,6 +605,8 @@ zffullpath(ZFMAP* zfmap, const char* key, char** pathp)
     size_t klen, pxlen, flen;
     char* path = NULL;
 
+    ZTRACE(6,"map=%s key=%s",zfmap->map.url,key);
+
     klen = nulllen(key);
     pxlen = strlen(zfmap->root);
     flen = klen+pxlen+1+1;
@@ -597,7 +622,7 @@ zffullpath(ZFMAP* zfmap, const char* key, char** pathp)
     if(pathp) {*pathp = path; path = NULL;}
 done:
     nullfree(path)
-    return stat;
+    return ZUNTRACEX(stat,"path=%s",(pathp?*pathp:"null"));
 }
 
 static int
@@ -621,49 +646,46 @@ done:
 static int
 platformerr(int err)
 {
-     switch (err) {
-     case ENOENT: err = NC_ENOTFOUND; break; /* File does not exist */
+    ZTRACE(6,"err=%d",err);
+    switch (err) {
+     case ENOENT: err = NC_ENOOBJECT; break; /* File does not exist */
      case ENOTDIR: err = NC_EEMPTY; break; /* no content */
      case EACCES: err = NC_EAUTH; break; /* file permissions */
      case EPERM:  err = NC_EAUTH; break; /* ditto */
      default: break;
      }
-     return err;
+     return ZUNTRACE(err);
 }
 
 /* Test type of the specified file.
 @return NC_NOERR if found and is a content-bearing object (file)
 @return NC_EEMPTY if exists but is not-content-bearing (a directory)
-@return NC_ENOTFOUND if not found
+@return NC_ENOOBJECT if not found
 */
 static int
-platformtestcontentbearing(ZFMAP* zfmap, const char* truepath)
+platformtestcontentbearing(ZFMAP* zfmap, const char* canonpath)
 {
     int ret = 0;
     struct stat buf;
-    char* local = NULL;
     
-    ZTRACE(6,"map=%s truepath=%s",zfmap->map.url,truepath);
-
-    /* Localize */
-    if((ret = nczm_localize(truepath,&local,LOCALIZE))) goto done;
+    ZTRACE(6,"map=%s canonpath=%s",zfmap->map.url,canonpath);
 
     errno = 0;
-    if((ret = stat(local, &buf)) < 0) {
+    ret = NCstat(canonpath, &buf);
+    ZTRACEMORE(6,"\tstat: ret=%d, errno=%d st_mode=%d",ret,errno,buf.st_mode);
+    if(ret < 0) {
 	ret = platformerr(errno);
     } else if(S_ISDIR(buf.st_mode)) {
         ret = NC_EEMPTY;
     } else
         ret = NC_NOERR;
-done:
-    nullfree(local);
     errno = 0;
     return ZUNTRACE(ret);
 }
 
 /* Create a file */
 static int
-platformcreatefile(ZFMAP* zfmap, const char* truepath, FD* fd)
+platformcreatefile(ZFMAP* zfmap, const char* canonpath, FD* fd)
 {
     int stat = NC_NOERR;
     int ioflags = 0;
@@ -671,7 +693,7 @@ platformcreatefile(ZFMAP* zfmap, const char* truepath, FD* fd)
     int mode = zfmap->map.mode;
     int permissions = NC_DEFAULT_ROPEN_PERMS;
 
-    ZTRACE(6,"map=%s truepath=%s",zfmap->map.url,truepath);
+    ZTRACE(6,"map=%s canonpath=%s",zfmap->map.url,canonpath);
     
     errno = 0;
     if(!fIsSet(mode, NC_WRITE))
@@ -692,10 +714,10 @@ platformcreatefile(ZFMAP* zfmap, const char* truepath, FD* fd)
     if(fIsSet(mode,NC_WRITE))
         createflags = (ioflags|O_CREAT);
 
-    /* Try to create file (will also localize) */
-    fd->fd = NCopen3(truepath, createflags, permissions);
+    /* Try to create file (will also NCpathcvt) */
+    fd->fd = NCopen3(canonpath, createflags, permissions);
     if(fd->fd < 0) { /* could not create */
-        stat = platformerr(errno);
+	stat = platformerr(errno);
         goto done; /* could not open */
     }
 done:
@@ -705,14 +727,14 @@ done:
 
 /* Open a file; fail if it does not exist */
 static int
-platformopenfile(ZFMAP* zfmap, const char* truepath, FD* fd)
+platformopenfile(ZFMAP* zfmap, const char* canonpath, FD* fd)
 {
     int stat = NC_NOERR;
     int ioflags = 0;
     int mode = zfmap->map.mode;
     int permissions = 0;
 
-    ZTRACE(6,"map=%s truepath=%s",zfmap->map.url,truepath);
+    ZTRACE(6,"map=%s canonpath=%s",zfmap->map.url,canonpath);
 
     errno = 0;
     if(!fIsSet(mode, NC_WRITE)) {
@@ -727,12 +749,12 @@ platformopenfile(ZFMAP* zfmap, const char* truepath, FD* fd)
 #endif
 
 #ifdef VERIFY
-    if(!verify(truepath,!FLAG_ISDIR))
+    if(!verify(canonpath,!FLAG_ISDIR))
         assert(!"expected file, have dir");
 #endif
 
     /* Try to open file  (will localize) */
-    fd->fd = NCopen3(truepath, ioflags, permissions);
+    fd->fd = NCopen3(canonpath, ioflags, permissions);
     if(fd->fd < 0)
         {stat = platformerr(errno); goto done;} /* could not open */
 done:
@@ -742,24 +764,24 @@ done:
 
 /* Create a dir */
 static int
-platformcreatedir(ZFMAP* zfmap, const char* truepath)
+platformcreatedir(ZFMAP* zfmap, const char* canonpath)
 {
     int ret = NC_NOERR;
     int mode = zfmap->map.mode;
 
-    ZTRACE(6,"map=%s truepath=%s",zfmap->map.url,truepath);
+    ZTRACE(6,"map=%s canonpath=%s",zfmap->map.url,canonpath);
 
     errno = 0;
     /* Try to access file as if it exists */
-    ret = NCaccess(truepath,ACCESS_MODE_EXISTS);
+    ret = NCaccess(canonpath,ACCESS_MODE_EXISTS);
     if(ret < 0) { /* it does not exist, then it can be anything */
 	if(fIsSet(mode,NC_WRITE)) {
 	    /* Try to create it */
             /* Create the directory using mkdir */
-   	    if(NCmkdir(truepath,NC_DEFAULT_DIR_PERMS) < 0)
+   	    if(NCmkdir(canonpath,NC_DEFAULT_DIR_PERMS) < 0)
 	        {ret = platformerr(errno); goto done;}
 	    /* try to access again */
-	    ret = NCaccess(truepath,ACCESS_MODE_EXISTS);
+	    ret = NCaccess(canonpath,ACCESS_MODE_EXISTS);
     	    if(ret < 0)
 	        {ret = platformerr(errno); goto done;}
 	} else
@@ -773,15 +795,15 @@ done:
 
 /* Open a dir; fail if it does not exist */
 static int
-platformopendir(ZFMAP* zfmap, const char* truepath)
+platformopendir(ZFMAP* zfmap, const char* canonpath)
 {
     int ret = NC_NOERR;
 
-    ZTRACE(6,"map=%s truepath=%s",zfmap->map.url,truepath);
+    ZTRACE(6,"map=%s canonpath=%s",zfmap->map.url,canonpath);
 
     errno = 0;
     /* Try to access file as if it exists */
-    ret = NCaccess(truepath,ACCESS_MODE_EXISTS);
+    ret = NCaccess(canonpath,ACCESS_MODE_EXISTS);
     if(ret < 0)
 	{ret = platformerr(errno); goto done;}	
 done:
@@ -804,7 +826,7 @@ There are several possibilities:
 
 #ifdef _WIN32
 static int
-platformdircontent(ZFMAP* zfmap, const char* truepath, NClist* contents)
+platformdircontent(ZFMAP* zfmap, const char* canonpath, NClist* contents)
 {
     int ret = NC_NOERR;
     errno = 0;
@@ -815,20 +837,20 @@ platformdircontent(ZFMAP* zfmap, const char* truepath, NClist* contents)
     size_t len;
     char* d = NULL;
 
-    ZTRACE(6,"map=%s truepath=%s",zfmap->map.url,truepath);
+    ZTRACE(6,"map=%s canonpath=%s",zfmap->map.url,canonpath);
 
-    switch (ret = platformtestcontentbearing(zfmap, truepath)) {
+    switch (ret = platformtestcontentbearing(zfmap, canonpath)) {
     case NC_EEMPTY: ret = NC_NOERR; break; /* directory */    
     case NC_NOERR: ret = NC_EEMPTY; goto done;
     default: goto done;
     }
 
     /* We need to process the path to make it work with FindFirstFile */
-    len = strlen(truepath);
+    len = strlen(canonpath);
     /* Need to terminate path with '/''*' */
     ffpath = (char*)malloc(len+2+1);
-    memcpy(ffpath,truepath,len);
-    if(truepath[len-1] != '/') {
+    memcpy(ffpath,canonpath,len);
+    if(canonpath[len-1] != '/') {
 	ffpath[len] = '/';	
 	len++;
     }
@@ -836,7 +858,8 @@ platformdircontent(ZFMAP* zfmap, const char* truepath, NClist* contents)
     ffpath[len] = '\0';
 
     /* localize it */
-    if((ret = nczm_localize(ffpath,&lpath,LOCALIZE))) goto done;
+    if((lpath = NCpathcvt(ffpath))==NULL)
+	{ret = NC_ENOMEM; goto done;}
     dir = FindFirstFile(lpath, &FindFileData);
     if(dir == INVALID_HANDLE_VALUE) {
 	/* Distinquish not-a-directory from no-matching-file */
@@ -851,7 +874,6 @@ platformdircontent(ZFMAP* zfmap, const char* truepath, NClist* contents)
 	}
     }
     do {
-	char* p = NULL;
 	const char* name = NULL;
         name = FindFileData.cFileName;
 	if(strcmp(name,".")==0 || strcmp(name,"..")==0)
@@ -871,21 +893,21 @@ done:
 #else /*!_WIN32*/
 
 static int
-platformdircontent(ZFMAP* zfmap, const char* truepath, NClist* contents)
+platformdircontent(ZFMAP* zfmap, const char* canonpath, NClist* contents)
 {
     int ret = NC_NOERR;
     errno = 0;
     DIR* dir = NULL;
 
-    ZTRACE(6,"map=%s truepath=%s",zfmap->map.url,truepath);
+    ZTRACE(6,"map=%s canonpath=%s",zfmap->map.url,canonpath);
 
-    switch (ret = platformtestcontentbearing(zfmap, truepath)) {
+    switch (ret = platformtestcontentbearing(zfmap, canonpath)) {
     case NC_EEMPTY: ret = NC_NOERR; break; /* directory */    
     case NC_NOERR: ret = NC_EEMPTY; goto done; 
     default: goto done;
     }
 
-    dir = NCopendir(truepath);
+    dir = NCopendir(canonpath);
     if(dir == NULL)
         {ret = platformerr(errno); goto done;}
     for(;;) {
@@ -926,7 +948,7 @@ platformdeleter(ZFMAP* zfmap, NClist* segments, int depth)
     if((path = NCpathcvt(tmp))==NULL) {ret = NC_ENOMEM; goto done;}
 
     errno = 0;
-    ret = stat(path, &statbuf);
+    ret = NCstat(path, &statbuf);
     if(ret < 0) {
         if(errno == ENOENT) {ret = NC_NOERR; goto done;}
 	else {ret = platformerr(errno); goto done;}
@@ -970,17 +992,18 @@ done:
 #endif /*0*/
 
 static int
-platformdeleter(ZFMAP* zfmap, NCbytes* truepath, int delroot, int depth)
+platformdeleter(ZFMAP* zfmap, NCbytes* canonpath, int delroot, int depth)
 {
     int ret = NC_NOERR;
     int i;
-    NClist* contents = nclistnew();
-    size_t tpathlen = ncbyteslength(truepath);
+    NClist* subfiles = nclistnew();
+    size_t tpathlen = ncbyteslength(canonpath);
     char* local = NULL;
 
-    ZTRACE(6,"map=%s truepath=%s delroot=%d depth=%d",zfmap->map.url,truepath,delroot,depth);
+    local = ncbytescontents(canonpath);
+    ZTRACE(6,"map=%s canonpath=%s delroot=%d depth=%d",zfmap->map.url,local,delroot,depth);
 
-    ret = platformdircontent(zfmap, ncbytescontents(truepath), contents);
+    ret = platformdircontent(zfmap, local, subfiles);
 #ifdef DEBUG
     {int i;
 	fprintf(stderr,"xxx: contents:\n");
@@ -991,21 +1014,20 @@ platformdeleter(ZFMAP* zfmap, NCbytes* truepath, int delroot, int depth)
 #endif
     switch (ret) {
     case NC_NOERR: /* recurse to remove levels below */
-        for(i=0;i<nclistlength(contents);i++) {
-	    const char* name = nclistget(contents,i);
+        for(i=0;i<nclistlength(subfiles);i++) {
+	    const char* name = nclistget(subfiles,i);
             /* append name to current path */
-            ncbytescat(truepath, "/");
-            ncbytescat(truepath, name);
+            ncbytescat(canonpath, "/");
+            ncbytescat(canonpath, name);
             /* recurse */
-            if ((ret = platformdeleter(zfmap, truepath,delroot,depth+1))) goto done;
-            ncbytessetlength(truepath,tpathlen); /* reset */
-	    ncbytesnull(truepath);
+            if ((ret = platformdeleter(zfmap, canonpath,delroot,depth+1))) goto done;
+            ncbytessetlength(canonpath,tpathlen); /* reset */
+	    ncbytesnull(canonpath);
+	    local = ncbytescontents(canonpath);
 	}
 	if(depth > 0 || delroot) {
-	    /* localize and delete */
-	    if((ret = nczm_localize(ncbytescontents(truepath),&local,LOCALIZE))) goto done;
 #ifdef DEBUG
-fprintf(stderr,"xxx: remove:  %s\n",local);
+fprintf(stderr,"xxx: remove:  %s\n",canonpath);
 #endif
             if(NCrmdir(local) < 0) { /* kill this dir */
 #ifdef DEBUG
@@ -1018,11 +1040,8 @@ fprintf(stderr,"xxx: remove: errno=%d|%s\n",errno,nc_strerror(errno));
 	break;    
     case NC_EEMPTY: /* Not a directory */
 	ret = NC_NOERR;
-        /* localize and delete */
-	if(local) {nullfree(local); local = NULL;}
-	if((ret = nczm_localize(ncbytescontents(truepath),&local,LOCALIZE))) goto done;
 #ifdef DEBUG
-fprintf(stderr,"xxx: remove:  %s\n",local);
+fprintf(stderr,"xxx: remove:  %s\n",canonpath);
 #endif
         if(NCremove(local) < 0) {/* kill this file */
 #ifdef DEBUG
@@ -1038,10 +1057,10 @@ fprintf(stderr,"xxx: remove: errno=%d|%s\n",errno,nc_strerror(errno));
     }
 
 done:
-    nclistfreeall(contents);
-    nullfree(local);
-    ncbytessetlength(truepath,tpathlen);
-    ncbytesnull(truepath);
+    errno = 0;
+    nclistfreeall(subfiles);
+    ncbytessetlength(canonpath,tpathlen);
+    ncbytesnull(canonpath);
     return ZUNTRACE(ret);
 }
 
@@ -1050,17 +1069,17 @@ static int
 platformdelete(ZFMAP* zfmap, const char* rootpath, int delroot)
 {
     int stat = NC_NOERR;
-    NCbytes* truepath = ncbytesnew();
+    NCbytes* canonpath = ncbytesnew();
 
     ZTRACE(6,"map=%s rootpath=%s delroot=%d",zfmap->map.url,rootpath,delroot);
     
     if(rootpath == NULL || strlen(rootpath) == 0) goto done;
-    ncbytescat(truepath,rootpath);
+    ncbytescat(canonpath,rootpath);
     if(rootpath[strlen(rootpath)-1] == '/') /* elide trailing '/' */
-	ncbytessetlength(truepath,ncbyteslength(truepath)-1);
-    if((stat = platformdeleter(zfmap,truepath,delroot,0))) goto done;
+	ncbytessetlength(canonpath,ncbyteslength(canonpath)-1);
+    if((stat = platformdeleter(zfmap,canonpath,delroot,0))) goto done;
 done:
-    ncbytesfree(truepath);
+    ncbytesfree(canonpath);
     errno = 0;
     return ZUNTRACE(stat);
 }
@@ -1077,7 +1096,7 @@ platformseek(ZFMAP* zfmap, FD* fd, int pos, size64_t* sizep)
     ZTRACE(6,"map=%s fd=%d pos=%d",zfmap->map.url,(fd?fd->fd:-1),pos);
 
     errno = 0;
-    ret = fstat(fd->fd, &statbuf);    
+    ret = NCfstat(fd->fd, &statbuf);    
     if(ret < 0)
 	{ret = platformerr(errno); goto done;}
     if(sizep) size = *sizep; else size = 0;
@@ -1107,6 +1126,7 @@ platformread(ZFMAP* zfmap, FD* fd, size64_t count, void* content)
 	readpoint += red;
     }
 done:
+    errno = 0;
     return ZUNTRACE(stat);
 }
 
@@ -1184,7 +1204,25 @@ verify(const char* path, int isdir)
     ret = NCaccess(path,ACCESS_MODE_EXISTS);
     if(ret < 0)
         return 1; /* If it does not exist, then it can be anything */
-    ret = stat(path,&buf);
+    ret = NCstat(path,&buf);
+    if(ret < 0) abort();
+    if(isdir && S_ISDIR(buf.st_mode)) return 1;
+    if(!isdir && S_ISREG(buf.st_mode)) return 1;           
+    return 0;
+}
+
+static int
+verifykey(const char* key, int isdir)
+{
+    int ret = 0;
+    struct stat buf;
+
+    if(key[0] == '/') key++; /* Want relative name */
+
+    ret = NCaccess(key,ACCESS_MODE_EXISTS);
+    if(ret < 0)
+        return 1; /* If it does not exist, then it can be anything */
+    ret = NCstat(key,&buf);
     if(ret < 0) abort();
     if(isdir && S_ISDIR(buf.st_mode)) return 1;
     if(!isdir && S_ISREG(buf.st_mode)) return 1;           
@@ -1193,21 +1231,21 @@ verify(const char* path, int isdir)
 #endif
 
 #if 0
-/* Return NC_EINVAL if path does not exist; els 1/0 in isdirp and local path in truepathp */
+/* Return NC_EINVAL if path does not exist; els 1/0 in isdirp and local path in canonpathp */
 static int
-testifdir(const char* path, int* isdirp, char** truepathp)
+testifdir(const char* path, int* isdirp, char** canonpathp)
 {
     int ret = NC_NOERR;
     char* tmp = NULL;
-    char* truepath = NULL;
+    char* canonpath = NULL;
     struct stat statbuf;
 
     /* Make path be windows compatible */
     if((ret = nczm_fixpath(path,&tmp))) goto done;
-    if((truepath = NCpathcvt(tmp))==NULL) {ret = NC_ENOMEM; goto done;}
+    if((canonpath = NCpathcvt(tmp))==NULL) {ret = NC_ENOMEM; goto done;}
 
     errno = 0;
-    ret = stat(truepath, &statbuf);
+    ret = NCstat(canonpath, &statbuf);
     if(ret < 0) {
         if(errno == ENOENT)
 	    ret = NC_ENOTFOUND;  /* path does not exist */
@@ -1219,11 +1257,11 @@ testifdir(const char* path, int* isdirp, char** truepathp)
     if(isdirp) {
         if(S_ISDIR(statbuf.st_mode)) {*isdirp = 1;} else {*isdirp = 0;}
     }
-    if(truepathp) {*truepathp = truepath; truepath = NULL;}
+    if(canonpathp) {*canonpathp = canonpath; canonpath = NULL;}
 done:
     errno = 0;
     nullfree(tmp);
-    nullfree(truepath);
+    nullfree(canonpath);
     return ZUNTRACE(ret);    
 }
 #endif /* 0 */
